TREE IF A OUTER NODE IS FOUND, THEN ADD ZERO QUANTITY OF THE INNER NODES THAT IT IS PART OF. Protein Amino Acids: https://en.wikipedia.org/wiki/Amino_acid { } Vitamin C https://www.iherb.com/blog/vitamin-c-forms/994 6 (or more) different forms: [ "Vitamin C, Ascorbic Acid", "Ascorbic Acid" ]: ASCORBIC ACID: ASCORBATE AND VITAMIN C METABOLITES, ESTER-C: VITAMIN C WITH BIOFLAVONOIDS: LIPOSOMAL VITAMIN C: